# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ostorlab/agent/message/proto/v3/asset/file/api_schema/graphql/graphql.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='ostorlab/agent/message/proto/v3/asset/file/api_schema/graphql/graphql.proto',
  package='ostorlab.agent.message.proto.v3.asset.file.api_schema.graphql',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nKostorlab/agent/message/proto/v3/asset/file/api_schema/graphql/graphql.proto\x12=ostorlab.agent.message.proto.v3.asset.file.api_schema.graphql\"\'\n\x0f\x41ndroidMetadata\x12\x14\n\x0cpackage_name\x18\x01 \x01(\t\" \n\x0bIOSMetadata\x12\x11\n\tbundle_id\x18\x01 \x01(\t\"\xd3\x02\n\x07Message\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\x0c\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x13\n\x0b\x63ontent_url\x18\x03 \x01(\t\x12j\n\x10\x61ndroid_metadata\x18\x04 \x01(\x0b\x32N.ostorlab.agent.message.proto.v3.asset.file.api_schema.graphql.AndroidMetadataH\x00\x12\x62\n\x0cios_metadata\x18\x05 \x01(\x0b\x32J.ostorlab.agent.message.proto.v3.asset.file.api_schema.graphql.IOSMetadataH\x00\x12\x14\n\x0c\x65ndpoint_url\x18\x06 \x01(\t\x12\x1c\n\x0bschema_type\x18\x07 \x01(\t:\x07graphqlB\x10\n\x0emetadata_oneof'
)




_ANDROIDMETADATA = _descriptor.Descriptor(
  name='AndroidMetadata',
  full_name='ostorlab.agent.message.proto.v3.asset.file.api_schema.graphql.AndroidMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='package_name', full_name='ostorlab.agent.message.proto.v3.asset.file.api_schema.graphql.AndroidMetadata.package_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=142,
  serialized_end=181,
)


_IOSMETADATA = _descriptor.Descriptor(
  name='IOSMetadata',
  full_name='ostorlab.agent.message.proto.v3.asset.file.api_schema.graphql.IOSMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='bundle_id', full_name='ostorlab.agent.message.proto.v3.asset.file.api_schema.graphql.IOSMetadata.bundle_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=183,
  serialized_end=215,
)


_MESSAGE = _descriptor.Descriptor(
  name='Message',
  full_name='ostorlab.agent.message.proto.v3.asset.file.api_schema.graphql.Message',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='content', full_name='ostorlab.agent.message.proto.v3.asset.file.api_schema.graphql.Message.content', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path', full_name='ostorlab.agent.message.proto.v3.asset.file.api_schema.graphql.Message.path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='content_url', full_name='ostorlab.agent.message.proto.v3.asset.file.api_schema.graphql.Message.content_url', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='android_metadata', full_name='ostorlab.agent.message.proto.v3.asset.file.api_schema.graphql.Message.android_metadata', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ios_metadata', full_name='ostorlab.agent.message.proto.v3.asset.file.api_schema.graphql.Message.ios_metadata', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='endpoint_url', full_name='ostorlab.agent.message.proto.v3.asset.file.api_schema.graphql.Message.endpoint_url', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='schema_type', full_name='ostorlab.agent.message.proto.v3.asset.file.api_schema.graphql.Message.schema_type', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"graphql".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='metadata_oneof', full_name='ostorlab.agent.message.proto.v3.asset.file.api_schema.graphql.Message.metadata_oneof',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=218,
  serialized_end=557,
)

_MESSAGE.fields_by_name['android_metadata'].message_type = _ANDROIDMETADATA
_MESSAGE.fields_by_name['ios_metadata'].message_type = _IOSMETADATA
_MESSAGE.oneofs_by_name['metadata_oneof'].fields.append(
  _MESSAGE.fields_by_name['android_metadata'])
_MESSAGE.fields_by_name['android_metadata'].containing_oneof = _MESSAGE.oneofs_by_name['metadata_oneof']
_MESSAGE.oneofs_by_name['metadata_oneof'].fields.append(
  _MESSAGE.fields_by_name['ios_metadata'])
_MESSAGE.fields_by_name['ios_metadata'].containing_oneof = _MESSAGE.oneofs_by_name['metadata_oneof']
DESCRIPTOR.message_types_by_name['AndroidMetadata'] = _ANDROIDMETADATA
DESCRIPTOR.message_types_by_name['IOSMetadata'] = _IOSMETADATA
DESCRIPTOR.message_types_by_name['Message'] = _MESSAGE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AndroidMetadata = _reflection.GeneratedProtocolMessageType('AndroidMetadata', (_message.Message,), {
  'DESCRIPTOR' : _ANDROIDMETADATA,
  '__module__' : 'ostorlab.agent.message.proto.v3.asset.file.api_schema.graphql.graphql_pb2'
  # @@protoc_insertion_point(class_scope:ostorlab.agent.message.proto.v3.asset.file.api_schema.graphql.AndroidMetadata)
  })
_sym_db.RegisterMessage(AndroidMetadata)

IOSMetadata = _reflection.GeneratedProtocolMessageType('IOSMetadata', (_message.Message,), {
  'DESCRIPTOR' : _IOSMETADATA,
  '__module__' : 'ostorlab.agent.message.proto.v3.asset.file.api_schema.graphql.graphql_pb2'
  # @@protoc_insertion_point(class_scope:ostorlab.agent.message.proto.v3.asset.file.api_schema.graphql.IOSMetadata)
  })
_sym_db.RegisterMessage(IOSMetadata)

Message = _reflection.GeneratedProtocolMessageType('Message', (_message.Message,), {
  'DESCRIPTOR' : _MESSAGE,
  '__module__' : 'ostorlab.agent.message.proto.v3.asset.file.api_schema.graphql.graphql_pb2'
  # @@protoc_insertion_point(class_scope:ostorlab.agent.message.proto.v3.asset.file.api_schema.graphql.Message)
  })
_sym_db.RegisterMessage(Message)


# @@protoc_insertion_point(module_scope)
