import{d as o,M as s,P as e,N as a,W as i,i as p,t as c}from"./83qOXOD1.js";import{c as m,u}from"./DgDQCLwe.js";import{u as l}from"./D0znOYnB.js";import{V as d}from"./PNXzkSQq.js";import{_ as f}from"./DlAUqK2U.js";import"./C3z5vVQS.js";import"./CwKIB8UZ.js";import"./yj3CsVEC.js";import"./DmN29qaT.js";import"./B7E3ychy.js";const _=o({name:"Vulnerability",components:{VulnerabilityDetail:d},data(){return{scanner:{endpoint:"",name:"",apiKey:""}}},computed:{...s(l,["scanners"])},mounted(){const n=this.scanners.find(r=>m(r.endpoint)===(this._.provides[e]||this.$route).params.scanner);n===void 0?(this.reportError("Scanner not found"),this.$router.push({name:"scan-list"})):this.scanner=n},methods:{...a(u,["reportError"])}});function h(n,r,v,$,y,S){const t=p("VulnerabilityDetail");return c(),i(t,{"scan-id":(n._.provides[e]||n.$route).params.scan,scanner:n.scanner,"vuln-title":(n._.provides[e]||n.$route).params.vuln},null,8,["scan-id","scanner","vuln-title"])}const A=f(_,[["render",h]]);export{A as default};
